@@ -23,6 +23,10 @@
 
 #include <stdio.h>
 
+#define CONFIG_VERSION_OPTION  "config_version"
+
+#define CONFIG_PRIORITY_DEFAULT 1000
+
 #define CONFIG_BOOLEAN(option) (*((int *)((option)->value)))
 #define CONFIG_BOOLEAN_DEFAULT(option) (*((int *)((option)->default_value)))
 
@@ -46,11 +50,23 @@ struct t_config_option;
 struct t_config_file
 {
     struct t_weechat_plugin *plugin;       /* plugin which created this cfg */
+    int priority;                          /* config files are sorted by    */
+                                           /* priority then name            */
     char *name;                            /* name (example: "weechat")     */
     char *filename;                        /* filename (without path)       */
                                            /* (example: "weechat.conf")     */
     FILE *file;                            /* file pointer                  */
-    int (*callback_reload)                 /* callback for reloading file   */
+    int version;                           /* config version (default=1)    */
+    int version_read;                      /* config version read in file   */
+    struct t_hashtable *(*callback_update) /* callback for version update   */
+    (const void *pointer,
+     void *data,
+     struct t_config_file *config_file,
+     int version_read,
+     struct t_hashtable *data_read);
+    const void *callback_update_pointer;   /* pointer sent to callback      */
+    void *callback_update_data;            /* data sent to callback         */
+    int (*callback_reload)                 /* callback for config reload    */
     (const void *pointer,
      void *data,
      struct t_config_file *config_file);
@@ -165,6 +181,9 @@ struct t_config_option
 extern struct t_config_file *config_files;
 extern struct t_config_file *last_config_file;
 
+extern char *config_option_type_string[];
+
+extern int config_file_valid (struct t_config_file *config_file);
 extern struct t_config_file *config_file_search (const char *name);
 extern struct t_config_file *config_file_new (struct t_weechat_plugin *plugin,
                                               const char *name,
@@ -173,6 +192,16 @@ extern struct t_config_file *config_file_new (struct t_weechat_plugin *plugin,
                                                                      struct t_config_file *config_file),
                                               const void *callback_reload_pointer,
                                               void *callback_reload_data);
+extern int config_file_set_version (struct t_config_file *config_file,
+                                    int version,
+                                    struct t_hashtable *(*callback_update)(const void *pointer,
+                                                                           void *data,
+                                                                           struct t_config_file *config_file,
+                                                                           int version_read,
+                                                                           struct t_hashtable *data_read),
+                                    const void *callback_update_pointer,
+                                    void *callback_update_data);
+extern struct t_arraylist *config_file_get_configs_by_priority ();
 extern struct t_config_section *config_file_new_section (struct t_config_file *config_file,
                                                          const char *name,
                                                          int user_can_add_options,
@@ -213,7 +242,7 @@ extern struct t_config_section *config_file_new_section (struct t_config_file *c
                                                          const void *callback_delete_option_pointer,
                                                          void *callback_delete_option_data);
 extern struct t_config_section *config_file_search_section (struct t_config_file *config_file,
-                                                            const char *section_name);
+                                                            const char *name);
 extern struct t_config_option *config_file_new_option (struct t_config_file *config_file,
                                                        struct t_config_section *section,
                                                        const char *name, const char *type,
@@ -259,6 +288,9 @@ extern int config_file_option_set (struct t_config_option *option,
                                    const char *value, int run_callback);
 extern int config_file_option_set_null (struct t_config_option *option,
                                         int run_callback);
+extern int config_file_option_set_default (struct t_config_option *option,
+                                           const char *value,
+                                           int run_callback);
 extern int config_file_option_toggle (struct t_config_option *option,
                                       const char **values, int num_values,
                                       int run_callback);
