@@ -334,10 +334,7 @@ eval_string_range_chars (const char *range)
 
 end:
     if (string)
-    {
-        result = *string;
-        string_dyn_free (string, 0);
-    }
+        result = string_dyn_free (string, 0);
 
     return (result) ? result : strdup ("");
 }
@@ -1170,8 +1167,8 @@ char *
 eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
                       struct t_eval_context *eval_context)
 {
-    char *value, *old_value, *var_name, str_value[128], *pos;
-    const char *ptr_value, *hdata_name, *ptr_var_name;
+    char *value, *old_value, *var_name, str_value[128], *pos, *property;
+    const char *ptr_value, *hdata_name, *ptr_var_name, *pos_open_paren;
     int type, debug_id;
     struct t_hashtable *hashtable;
 
@@ -1260,10 +1257,26 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
             if (pos)
             {
                 /*
-                 * for a hashtable, if there is a "." after name of hdata,
-                 * get the value for this key in hashtable
+                 * for a hashtable, if there is a "." after name of hdata:
+                 * 1) If "()" is at the end, it is a function call to
+                 *    hashtable_get_string().
+                 * 2) Otherwise, get the value for this key in hashtable.
                  */
                 hashtable = pointer;
+
+                pos_open_paren = strchr (pos, '(');
+                if (pos_open_paren
+                    && (pos_open_paren > pos + 1)
+                    && (pos_open_paren[1] == ')'))
+                {
+                    property = string_strndup (pos + 1,
+                                               pos_open_paren - pos - 1);
+                    ptr_value = hashtable_get_string (hashtable, property);
+                    free (property);
+                    value = (ptr_value) ? strdup (ptr_value) : NULL;
+                    break;
+                }
+
                 ptr_value = hashtable_get (hashtable, pos + 1);
                 if (ptr_value)
                 {
