@@ -60,7 +60,7 @@ hashtable_get_type (const char *type)
 
     for (i = 0; i < HASHTABLE_NUM_TYPES; i++)
     {
-        if (string_strcasecmp (hashtable_type_string[i], type) == 0)
+        if (strcmp (hashtable_type_string[i], type) == 0)
             return i;
     }
 
@@ -747,13 +747,13 @@ hashtable_get_list_keys (struct t_hashtable *hashtable)
 int
 hashtable_get_integer (struct t_hashtable *hashtable, const char *property)
 {
-    if (hashtable && property)
-    {
-        if (string_strcasecmp (property, "size") == 0)
-            return hashtable->size;
-        else if (string_strcasecmp (property, "items_count") == 0)
-            return hashtable->items_count;
-    }
+    if (!hashtable || !property)
+        return 0;
+
+    if (strcmp (property, "size") == 0)
+        return hashtable->size;
+    else if (strcmp (property, "items_count") == 0)
+        return hashtable->items_count;
 
     return 0;
 }
@@ -1003,23 +1003,23 @@ hashtable_get_keys_values (struct t_hashtable *hashtable,
 const char *
 hashtable_get_string (struct t_hashtable *hashtable, const char *property)
 {
-    if (hashtable && property)
-    {
-        if (string_strcasecmp (property, "type_keys") == 0)
-            return hashtable_type_string[hashtable->type_keys];
-        else if (string_strcasecmp (property, "type_values") == 0)
-            return hashtable_type_string[hashtable->type_values];
-        else if (string_strcasecmp (property, "keys") == 0)
-            return hashtable_get_keys_values (hashtable, 1, 0, 0);
-        else if (string_strcasecmp (property, "keys_sorted") == 0)
-            return hashtable_get_keys_values (hashtable, 1, 1, 0);
-        else if (string_strcasecmp (property, "values") == 0)
-            return hashtable_get_keys_values (hashtable, 0, 0, 1);
-        else if (string_strcasecmp (property, "keys_values") == 0)
-            return hashtable_get_keys_values (hashtable, 1, 0, 1);
-        else if (string_strcasecmp (property, "keys_values_sorted") == 0)
-            return hashtable_get_keys_values (hashtable, 1, 1, 1);
-    }
+    if (!hashtable || !property)
+        return NULL;
+
+    if (strcmp (property, "type_keys") == 0)
+        return hashtable_type_string[hashtable->type_keys];
+    else if (strcmp (property, "type_values") == 0)
+        return hashtable_type_string[hashtable->type_values];
+    else if (strcmp (property, "keys") == 0)
+        return hashtable_get_keys_values (hashtable, 1, 0, 0);
+    else if (strcmp (property, "keys_sorted") == 0)
+        return hashtable_get_keys_values (hashtable, 1, 1, 0);
+    else if (strcmp (property, "values") == 0)
+        return hashtable_get_keys_values (hashtable, 0, 0, 1);
+    else if (strcmp (property, "keys_values") == 0)
+        return hashtable_get_keys_values (hashtable, 1, 0, 1);
+    else if (strcmp (property, "keys_values_sorted") == 0)
+        return hashtable_get_keys_values (hashtable, 1, 1, 1);
 
     return NULL;
 }
@@ -1032,13 +1032,13 @@ void
 hashtable_set_pointer (struct t_hashtable *hashtable, const char *property,
                        void *pointer)
 {
-    if (hashtable && property)
-    {
-        if (string_strcasecmp (property, "callback_free_key") == 0)
-            hashtable->callback_free_key = pointer;
-        else if (string_strcasecmp (property, "callback_free_value") == 0)
-            hashtable->callback_free_value = pointer;
-    }
+    if (!hashtable || !property)
+        return;
+
+    if (strcmp (property, "callback_free_key") == 0)
+        hashtable->callback_free_key = pointer;
+    else if (strcmp (property, "callback_free_value") == 0)
+        hashtable->callback_free_value = pointer;
 }
 
 /*
